===============
Version History
===============

.. automodule:: petbox.dca
   :noindex:



1.0.3
-----

* Add documentation
* Genericize numerical integration
* Various refactoring


0.0.1 - 1.0.2
-------------

* Internal releases
